# 📋 ClipWatch
**ClipWatch** is a tiny utility that simplifies copy/paste-heavy workflows.  
It watches your clipboard and prints new entries to `stdout` as you copy them.

Use it to quickly build scripts, batch commands, or collect snippets—without constantly switching between windows or terminals.

## 🔧 Features

| Option | Description |
|--------|-------------|
| `-i`, `--ignore-first` | Ignore the clipboard value present at startup. |
| `-q`, `--quiet` | Don’t print clipboard contents to stdout. |
| `-s`, `--summary` | At program exit, copy all collected clipboard entries into the clipboard. |
| `-t`, `--transform <template>` | Replace `{}` in the template with each clipboard entry. |

## ✨ Examples
Let’s say you’re copying a bunch of YouTube URLs and want to download them all:

```bash
clipwatch -i -t "yt-dlp {}"
```

If you copy some URLs the output will be:
```
yt-dlp https://youtube.com/watch?v=abc123
yt-dlp https://youtube.com/watch?v=def456
yt-dlp https://youtube.com/watch?v=ghi789
```

Which you can pipe that directly into your shell:
```
clipwatch -i -t "yt-dlp {}" | bash
```

No manual typing, no window switching, no madness.

### 🧪 Another Example

Collect useful shell commands throughout your session and export them all at once:
```bash
clipwatch -s -q
# ...copy various shell snippets...
# press Ctrl+C to stop
```

At termination, the full history is copied into your clipboard as a single block.

## 🚀 Why Use ClipWatch?
- Automate your clipboard-to-terminal workflow
- Easily batch process copied content
- Turn copied text into live scripts
- Collect text snippets for notes or reuse
