mod config;
use std::sync::{Arc, Mutex};
use std::{process, thread, time};

use arboard::*;

fn main() {
    let conf = config::parse_config();

    let mut c = Clipboard::new().unwrap();
    let mut cstr = String::new();
    let ten_millis = time::Duration::from_millis(10);
    let stream: Arc<Mutex<Vec<String>>> = Arc::new(Mutex::new(vec![]));
    let cp_stream = stream.clone();

    let summary = conf.summary.clone();
    ctrlc::set_handler(move || {
        if summary {
            let mut fstr = String::new();
            let v = cp_stream.lock().unwrap();
            for i in 0..v.len() {
                fstr.push_str(&*format!("{}\n", v[i]));
            }
            Clipboard::new().unwrap().set_text(fstr).unwrap();
        }
        process::exit(0);
    })
    .expect("Error setting Ctrl-C handler");

    if conf.ignore_first {
        cstr = c.get_text().unwrap();
    }

    loop {
        let nstr = c.get_text();
        if nstr.is_err() {
            continue;
        }
        let nstr = nstr.unwrap();
        if nstr != cstr {
            let t_str = if let Some(transform) = conf.transform.as_ref() {
                transform.replace("{}", &nstr)
            } else {
                nstr.clone()
            };

            cstr = nstr;

            stream.lock().unwrap().push(t_str.clone());
            if !conf.quiet {
                println!("{}", t_str);
            }
        }
        thread::sleep(ten_millis);
    }
}
